export interface Rectangle {
  point: [number, number];
  size: [number, number];
}

export function boundsToRect(boundingClientRect: DOMRect): Rectangle {
  const {x, y, width, height} = boundingClientRect;
  return {point: [x, y], size: [width, height]};
}

export function getFocusRectangles(
    element: HTMLElement,
    consumer: (element: HTMLElement, boundingClientRect: Rectangle) => void): boolean {
  let doneAny = false;
  for (const child of element.children) {
    if (getFocusRectangles(child as HTMLElement, consumer)) {
      doneAny = true;
    }
  }
  if (doneAny) {
    return true;
  }
  if (element.tabIndex >= 0) {
    consumer(element, boundsToRect(element.getBoundingClientRect()));
    return true;
  }
  return false;
}
